/*!
   \file  flexrioapierrors.h
   \brief Declaration of FlexRIO status codes.
   Use niFlexRIO_GetError() to get additional information about these errors.
*/

#ifndef _FLEXRIOAPIERRORS_H_
#define _FLEXRIOAPIERRORS_H_

typedef enum
{
   NIFLEXRIO_Status_Success = 0,

   // The command was sent with invalid arguments. Check your arguments and try
   // again.
   NIFLEXRIO_Status_iFifoInvalidArguments = -304300,

   // The command that was sent does not exist.
   NIFLEXRIO_Status_iFifoInvalidCommand = -304301,

   // The command that was sent is not supported by this target.
   NIFLEXRIO_Status_iFifoUnsupportedCommand = -304302,

   // An internal error has occurred. Contact National Instruments technical
   // support at ni.com/support.
   NIFLEXRIO_Status_iFifoCommandTimeout = -304303,

   // An internal error has occurred. Contact National Instruments technical
   // support at ni.com/support.
   NIFLEXRIO_Status_iFifoCommandInternalError = -304304,

   // The command that was sent requires the FPGA IO to be enabled. Wait until
   // the IO is enabled and try again.
   NIFLEXRIO_Status_iFifoCommandSentWhenIoDisabled = -304305,

   // The requested interface is not implemented on this endpoint.
   NIFLEXRIO_Status_iFifoUnsupportedInterface = -304306,

   // The requested interface version is not compatible with hardware.
   NIFLEXRIO_Status_iFifoInterfaceVersionMismatch = -304307,

   // Internal HW Error, contact National Instruments.
   NIFLEXRIO_Status_iFifoUserClockNotToggling = -304308,

   // Internal HW Error, contact National Instruments.
   NIFLEXRIO_Status_iFifoResetTimeout = -304309,

   // Internal HW Error, contact National Instruments.
   NIFLEXRIO_Status_iFifoEnableTimeout = -304310,

   // Internal HW Error, contact National Instruments.
   NIFLEXRIO_Status_iFifoDisableTimeout = -304311,

   // The device has shut down to protect against excessive FPGA temperature.
   // Check airflow and cooling and redownload the bitfile. To avoid this error,
   // monitor the FPGA temperature, temperature shutdown threshold, and margin
   // of the FPGA. If necessary, reduce FPGA temperature.
   NIFLEXRIO_Status_ThermalShutdown = -304312,

   // The device has shut down to protect against excessive power consumption.
   // Check airflow and cooling and redownload the bitfile. To avoid this error,
   // monitor the power consumption, power shutdown threshold, and margin of the
   // device. If necessary, reduce FPGA power consumption.
   NIFLEXRIO_Status_PowerShutdown = -304313,

   // The device has not become ready within the expected time.  This may
   // indicate a problem with the hardware initialization or the system
   // configuration.  Use the IO Error property to check for further
   // information.
   NIFLEXRIO_Status_IoModuleNotReady = -304314,

   // Phase DAC calibration failed.
   NIFLEXRIO_Status_PhaseDacCalibrationFailed = -304315,

   // The IO Module PLL did not lock to the provided reference in time. Please
   // check your cable connections and system configuration and try again.
   NIFLEXRIO_Status_IoPllLockTimedout = -304316,

   // The IO Module was unable to configure. If you are using an external sample
   // clock, check your cable connections and system configuration and try
   // again.
   NIFLEXRIO_Status_IoJesdLinkError = -304317,

   // The IO Module was unable to configure. If you are using an external sample
   // clock, check your cable connections and system configuration and try
   // again.
   NIFLEXRIO_Status_IoClipPllLockTimedout = -304318,

   // Internal HW Error, contact National Instruments.
   NIFLEXRIO_Status_IoFirmwareRevTooLow = -304319,

   // Internal HW Error, contact National Instruments.
   NIFLEXRIO_Status_IoErrorFirmwareRevTooHigh = -304320,

   // Internal HW Error, contact National Instruments.
   NIFLEXRIO_Status_IoErrorRsvd0 = -304321,

   // Internal HW Error, contact National Instruments.
   NIFLEXRIO_Status_IoErrorRsvd1 = -304322,

   // Internal HW Error, contact National Instruments.
   NIFLEXRIO_Status_IoErrorRsvd2 = -304323,

   // Internal HW Error, contact National Instruments.
   NIFLEXRIO_Status_LinkCfgIoStratReadFailed = -304324,

   // Internal HW Error, contact National Instruments.
   NIFLEXRIO_Status_CalibrationWaitForIoTimeout = -304325,

   // Internal HW Error, contact National Instruments.
   NIFLEXRIO_Status_IsoPortNotReady = -304326,

   // Internal HW Error, contact National Instruments.
   NIFLEXRIO_Status_TdcNotReady = -304327,

   // Internal HW Error, contact National Instruments.
   NIFLEXRIO_Status_TdcMeasurementFailed = -304328,

   // DSP reset timed out waiting for a state transition.
   NIFLEXRIO_Status_DspResetTimeoutWaitingForState = -304329,

   // Timed out waiting for baseboard PLL to lock. Check that the baseboard
   // ribbon cable is correctly connected.
   NIFLEXRIO_Status_BaseboardPllLockTimeout = -304330,

   // The specified QSFP connector is not present. Check that the cable is
   // correctly connected.
   NIFLEXRIO_Status_QsfpCableNotPresent = -304331,

   // Failed to reset the QSFP ports.
   NIFLEXRIO_Status_QsfpResetFailed = -304332,

   // The software encountered an unspecific error.
   NIFLEXRIO_Status_SoftwareError = -304400,

   // The number of channels requested by ReadStream does not match those
   // enabled on the stream, or there are no channels enabled via the API.
   NIFLEXRIO_Status_StreamWaveformMismatch = -304401,

   // A user-provided pointer was NULL.  This function does not have defined
   // behavior for NULL
   NIFLEXRIO_Status_NullPointer = -304402,

   // User accessed an attribute using the wrong data type.
   NIFLEXRIO_Status_AttributeTypeMismatch = -304403,

   // Attribute is undefined or not present in the currently running session.
   NIFLEXRIO_Status_AttributeNotAvailable = -304404,

   // User accessed a stream that either does not exist or is not discoverable.
   NIFLEXRIO_Status_InvalidStreamIndex = -304405,

   // User accessed a calibration index that is out of bounds.
   NIFLEXRIO_Status_CalibrationOutOfBounds = -304406,

   // User tried to load a bitfile from flash, but the flash did not have
   // metadata for that image.
   NIFLEXRIO_Status_ImageMetadataAbsent = -304407,

   // Requested value is not a supported value for this property. The property
   // value may be invalid because it conflicts with another property.
   NIFLEXRIO_Status_InvalidAttributeValue = -304408,

   // TClk is not supported when using an external sample clock.
   NIFLEXRIO_Status_TClkNotSupportedWithExternalSampleClock = -304409,

   // The source provided for the external sample clock is invalid.
   NIFLEXRIO_Status_ExternalSampleClockSourceNotSupported = -304410,

   // TClk resources are currently in use by another session.
   NIFLEXRIO_Status_TClkResourcesInUse = -304411,

   // Another session is already open to the specified device. Close the other
   // session and retry this operation.
   NIFLEXRIO_Status_MultipleSessionsDetected = -304412,

   // Attribute is write-only.
   NIFLEXRIO_Status_AttributeNotReadable = -304413,

   // Attribute is read-only.
   NIFLEXRIO_Status_AttributeNotWritable = -304414,

   // The stream entered an error state due to a FIFO overflow or a forced
   // error.  The read was unable to complete because the requested samples have
   // not arrived.
   NIFLEXRIO_Status_StreamTimedOutDueToStreamError = -304415,

   // The stream entered an cancelled state.  The read was unable to complete
   // because the requested samples have not arrived.
   NIFLEXRIO_Status_StreamTimedOutDueToStreamCancel = -304416,

   // The DRAM buffer did not become ready within the specified timeout.
   NIFLEXRIO_Status_DramNotReady = -304417,

   // The IO data did not become valid within the specified timeout.
   NIFLEXRIO_Status_DataNotValid = -304418,

   // The string provided could not be parsed due to a formatting error.
   NIFLEXRIO_Status_StringParsingError = -304419,

   // The string provided contains too many entries to be valid.
   NIFLEXRIO_Status_StringParsingTooManyEntries = -304420,

   // The string provided contains an invalid channel.
   NIFLEXRIO_Status_StringParsingInvalidChannel = -304421,

   // The string provided contains an invalid stream number.
   NIFLEXRIO_Status_StringParsingInvalidStream = -304422,

   // Attribute is present in the currently running session, but not at the
   // selected context.
   NIFLEXRIO_Status_AttributeContextMismatch = -304423,

   // Firmware update already in progress.
   NIFLEXRIO_Status_FirmwareUpdateInProgress = -304424,

   // Firmware update is not yet in progress.
   NIFLEXRIO_Status_FirmwareUpdateNotInProgress = -304425,

   // The DSP did not become ready within the timeout period.  This is likely a
   // result of an improper connection or behavior of the 'flexrio.dsp.reset N'
   // control or the 'flexrio.dsp.ready N' indicator.  Validate the behavior of
   // your FPGA diagram.
   NIFLEXRIO_Status_DspNotReady = -304426,

   // The onboard waveform looping buffer did not fill up within the timeout
   // period.  A write operation posted data for transfer to the FPGA, but the
   // FPGA did not report that all the data arrived.  Validate the behavior of
   // your FPGA diagram.
   NIFLEXRIO_Status_LoopBufferNotFilled = -304427,

   // The string provided contains an invalid clock number.
   NIFLEXRIO_Status_StringParsingInvalidClock = -304428,

   // This stream does not support the requested operation.  Verify the stream
   // number or the FPGA loaded.
   NIFLEXRIO_Status_InvalidStreamOperation = -304429,

   // This operation requires a device with an IO Module connected, but there is
   // no IO Module detected.
   NIFLEXRIO_Status_IoModuleNotPresent = -304430,

   // This firmware bundle is not valid or is not compatible with the selected
   // HW.
   NIFLEXRIO_Status_InvalidFirmwareBundle = -304431,

   // This firmware bundle is corrupt and cannot be parsed.
   NIFLEXRIO_Status_CorruptFirmwareBundle = -304432,

   // This firmware bundle is missing an expected file.
   NIFLEXRIO_Status_FileMissingInFirmwareBundle = -304433,

   // The input reference clock could not be divided down to a valid PLL input.
   NIFLEXRIO_Status_RefClkRangeUnsupported = -304434,

   // Requested User Clock frequency does not fall within supported range of
   // frequencies.
   NIFLEXRIO_Status_UserClockFreqInvalid = -304435,

   // User Clock configured for Bypass mode does not support Bypass
   // functionality.
   NIFLEXRIO_Status_BypassUnsupported = -304436,

   // Too many unique User Clock frequencies have been requested.
   NIFLEXRIO_Status_UserClockFreqCombinationUnsupported = -304437,

   // The software encountered an unspecific error.
   NIFLEXRIO_Status_GenericInternalError = -304500,

   // The API attempted to access an attribute with an unhandled data type.
   NIFLEXRIO_Status_UnhandledAttributeType = -304501,

   // The API attempted to access an function that has an incompatible version.
   NIFLEXRIO_Status_InternalVersionMismatch = -304502,

   // The API attempted to access a FIFO that transfers data in an unsupported
   // format.  Only integer FIFO types are supported.
   NIFLEXRIO_Status_UnsupportedTargetFifoType = -304503,

   // The requested Instruction FIFO is not accessible. Make sure it is present
   // in this bitfile.
   NIFLEXRIO_Status_iFifoNotAccessible = -304504,

   // The Instruction FIFO version on the device is not compatible with the
   // version supported by the driver. Update the bitfile loaded from flash
   // and/or recompile.
   NIFLEXRIO_Status_iFifoVersionMismatch = -304505,

   // The requested sensor was not found.
   NIFLEXRIO_Status_InvalidSensor = -304506,

   // This bitfile requires a newer driver for synchronization support.
   NIFLEXRIO_Status_ClipRequiresNewerDriverForSync = -304507,

   // An internal error has occurred. Contact National Instruments technical
   // support at ni.com/support.
   NIFLEXRIO_Status_InstructionFIFOCreditError = -304508,

   // An internal error has occurred. An invalid User Clock Frequency has been
   // requested.
   NIFLEXRIO_Status_UserClockFreqNotFound = -304509,

   // The temperature sensor could not be read and the calibration temperature
   // reading was not updated as part of the calibration procedure.
   NIFLEXRIO_Status_CalibrationNoTemperature = 304300,

   // The IO Module PLL is unlocked.
   NIFLEXRIO_Status_IoPllUnlockedWarning = 304316,

   // This FPGA was built with a version of target support with a known issue.
   // Rebuild the FPGA with updated target support to ensure data integrity.
   NIFLEXRIO_Status_FixedLogicResetIssue = 304317,

   NIFLEXRIO_Status_MemGuard = 0xFFFFFFFF
} NIFLEXRIO_Status;

#endif /* _FLEXRIOAPIERRORS_H_ */
